@@ -1,7 +1,7 @@
 /*
 // pgAgent - PostgreSQL Tools
 // 
-// Copyright (C) 2002 - 2014 The pgAdmin Development Team
+// Copyright (C) 2002 - 2021, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
 // pgagent.sql - pgAgent tables and functions
@@ -39,7 +39,7 @@ INSERT INTO pgagent.pga_jobclass (jclname) VALUES ('Data Export');
 INSERT INTO pgagent.pga_jobclass (jclname) VALUES ('Data Summarisation');
 INSERT INTO pgagent.pga_jobclass (jclname) VALUES ('Miscellaneous');
 -- Be sure to update pg_extension_config_dump() below and in
--- pgagent--unpackaged--3.4.sql when adding new classes.
+-- upgrade scripts etc, when adding new classes.
 
 
 CREATE TABLE pgagent.pga_job (
@@ -149,7 +149,7 @@ CREATE OR REPLACE FUNCTION pgagent.pgagent_schema_version() RETURNS int2 AS '
 BEGIN
     -- RETURNS PGAGENT MAJOR VERSION
     -- WE WILL CHANGE THE MAJOR VERSION, ONLY IF THERE IS A SCHEMA CHANGE
-    RETURN 3;
+    RETURN 4;
 END;
 ' LANGUAGE 'plpgsql' VOLATILE;
 
@@ -390,7 +390,7 @@ BEGIN
             IF minutetweak = TRUE THEN
         d := 1;
             ELSE
-        d := date_part(''YEAR'', runafter)::int2;
+        d := date_part(''MINUTE'', runafter)::int2;
             END IF;
             FOR i IN d .. 60 LOOP
                 IF jscminutes[i] = TRUE THEN
@@ -476,7 +476,7 @@ BEGIN
             (jscmonthdays = ''{f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,f,t}'' AND
              ((date_part(''MONTH'', nextrun) IN (1,3,5,7,8,10,12) AND date_part(''DAY'', nextrun) = 31) OR
               (date_part(''MONTH'', nextrun) IN (4,6,9,11) AND date_part(''DAY'', nextrun) = 30) OR
-              (date_part(''MONTH'', nextrun) = 2 AND ((pgagent.pga_is_leap_year(date_part(''DAY'', nextrun)::int2) AND date_part(''DAY'', nextrun) = 29) OR date_part(''DAY'', nextrun) = 28))))) AND
+              (date_part(''MONTH'', nextrun) = 2 AND ((pgagent.pga_is_leap_year(date_part(''YEAR'', nextrun)::int2) AND date_part(''DAY'', nextrun) = 29) OR date_part(''DAY'', nextrun) = 28))))) AND
             (jscmonths = ''{f,f,f,f,f,f,f,f,f,f,f,f}'' OR jscmonths[date_part(''MONTH'', nextrun)] = TRUE)) THEN
 
 
